<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fo="http://www.w3.org/1999/XSL/Format" exclude-result-prefixes="xs" version="2.0">

    <xsl:variable name="currentDate" select="current-date()"/>
    <xsl:variable name="currentTime" select="current-time()"/>
    <xsl:variable name="currentDateTime" select="dateTime($currentDate, $currentTime)"/>

    <!-- Data dump -->
    <xsl:template match="CatalogNumber"/>
    <xsl:template match="IssueNumber"/>
    <xsl:template match="CatalogName"/>
    <xsl:template match="Prefix"/>
    <xsl:template match="Range"/>
    <xsl:template match="Title"/>
    <xsl:template match="IssueName"/>
    <xsl:template match="Year"/>
    <xsl:template match="Page"/>

    <xsl:template match="/">
        <fo:root>
            <fo:layout-master-set>

                <!-- Odd Page Layout -->
                <fo:simple-page-master master-name="odd" page-height="11in" page-width="8.5in">
                    <fo:region-body region-name="text" margin-top="0.75in" margin-bottom="0.8in" margin-left="0.75in" margin-right="0.5in"/>
                    <fo:region-before region-name="odd-header" extent="0.5in"/>
                    <fo:region-after region-name="footer" extent="0.5in"/>
                </fo:simple-page-master>

                <!-- Even Page Layout -->
                <fo:simple-page-master master-name="even" page-height="11in" page-width="8.5in">
                    <fo:region-body region-name="text" margin-top="0.75in" margin-bottom="0.8in" margin-left="0.5in" margin-right="0.75in"/>
                    <fo:region-before region-name="even-header" extent="0.5in"/>
                    <fo:region-after region-name="footer" extent="0.5in"/>
                </fo:simple-page-master>

                <!-- Page Sequencing: Odd then Even -->
                <fo:page-sequence-master master-name="odd-even">
                    <fo:repeatable-page-master-alternatives>
                        <fo:conditional-page-master-reference odd-or-even="odd" master-reference="odd"/>
                        <fo:conditional-page-master-reference odd-or-even="even" master-reference="even"/>
                    </fo:repeatable-page-master-alternatives>
                </fo:page-sequence-master>
            </fo:layout-master-set>


            <!-- Flows to header, body, and footer -->
            <fo:page-sequence master-reference="odd-even" initial-page-number="1">
                <fo:static-content flow-name="odd-header">
                    <fo:block text-align="center" space-before=".25in" space-before.conditionality="retain">The Czechoslovak Specialist Index: 1939-2006.Jul/Aug</fo:block>
                </fo:static-content>
                <fo:static-content flow-name="even-header">
                    <fo:block text-align="center" space-before=".25in" space-before.conditionality="retain">The Czechoslovak Specialist Index: 1939-2006.Jul/Aug</fo:block>
                </fo:static-content>
                <fo:static-content flow-name="footer" text-align="center">
                    <fo:block>
                        <fo:page-number/>
                    </fo:block>
                </fo:static-content>
                <fo:flow flow-name="text">
                    <fo:block xsl:use-attribute-sets="base">
                        <xsl:apply-templates/>
                    </fo:block>
                </fo:flow>
            </fo:page-sequence>
        </fo:root>
    </xsl:template>

    <xsl:template match="List">
        <fo:block>©2009. Mark Wilson. All rights reserved. Knihtisk, 8825 Lund Hill Lane, Cotati CA 94931. www.knihtisk.org</fo:block>
        <fo:block>
            <xsl:value-of select="format-dateTime($currentDateTime, 'This revision created at [h]:[m]  [P] on [FNn], the [D] of  [MNn], [Y].')"/>
        </fo:block>
        <fo:block xsl:use-attribute-sets="rebus">
            <xsl:choose>
                <xsl:when test="contains (base-uri(/), 'POFIS-Ceska')">
                    <xsl:text>By POFIS Česká Republica Numbers</xsl:text>
                </xsl:when>
                <xsl:when test="contains(base-uri(/), 'POFIS-Slovenska')">
                    <xsl:text>By POFIS Slovenská Republica Numbers</xsl:text>
                </xsl:when>
                <xsl:when test="contains(base-uri(/), 'POFIS-Slovensky')">
                    <xsl:text>By POFIS Slovenský Stát Numbers</xsl:text>
                </xsl:when>
                <xsl:when test="contains(base-uri(/), 'Cechy')">
                    <xsl:text>By POFIS Protektorát Čechy a Morava Numbers</xsl:text>
                </xsl:when>
                <xsl:when test="contains(base-uri(/), 'Ceskosloven')">
                    <xsl:text>By POFIS Československo Numbers</xsl:text>
                </xsl:when>
                <xsl:when test="contains(base-uri(/), 'Bohemia')">
                    <xsl:text>By Scott Bohemia and Moravia Numbers</xsl:text>
                </xsl:when>
                <xsl:when test="contains(base-uri(/), 'Eastern')">
                    <xsl:text>By Scott Eastern Silesia Numbers</xsl:text>
                </xsl:when>
                <xsl:when test="contains(base-uri(/), 'Slovakia')">
                    <xsl:text>By Scott Slovakia Numbers</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>By Scott Czechoslovakia and The Czech Republic Numbers</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
        </fo:block>

        <xsl:for-each-group select="Item" group-by="concat(Prefix, CatalogNumber, Range)">
            <fo:block xsl:use-attribute-sets="base">
                <xsl:apply-templates select="CatalogNumber" mode="do"/>
                <xsl:for-each select="current-group()">
                    <xsl:apply-templates select="Title" mode="do"/>
                </xsl:for-each>
            </fo:block>
        </xsl:for-each-group>

    </xsl:template>

    <xsl:template match="CatalogNumber" mode="do">
        <fo:wrapper xsl:use-attribute-sets="numbers">
            <xsl:value-of select="../Prefix"/>
            <xsl:value-of select="."/>
            <xsl:value-of select="../Range"/>
            <xsl:text>: </xsl:text>
            <!--  <xsl:apply-templates select="../Title" mode="do"/> -->
        </fo:wrapper>
    </xsl:template>



    <xsl:template match="Title" mode="do">
        <fo:wrapper xsl:use-attribute-sets="title">
            <!-- <xsl:text>: </xsl:text> -->
            <xsl:choose>
                <xsl:when test="contains(.,'?') and not(substring-after(., '?'))">
                    <xsl:value-of select="."/>
                </xsl:when>
                <xsl:when test="contains(.,'!') and not(substring-after(., '!'))">
                    <xsl:value-of select="."/>
                </xsl:when>
                <xsl:when test="contains(.,'.') and not(substring-after(., '.'))">
                    <xsl:value-of select="."/>
                </xsl:when>
                <xsl:when test=". eq '[Title]'">
                    <xsl:text>Untitled.</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat(' ', normalize-space(.), '.')"/>
                </xsl:otherwise>
            </xsl:choose>
        </fo:wrapper>
        <xsl:apply-templates select="../IssueName" mode="do"/>
    </xsl:template>


    <xsl:template match="IssueName" mode="do">
        <fo:wrapper xsl:use-attribute-sets="base">
            <xsl:value-of select="concat(' ',., ' ')"/>
        </fo:wrapper>
        <xsl:apply-templates select="../Year" mode="do"/>
    </xsl:template>

    <xsl:template match="Year" mode="do">
        <fo:wrapper xsl:use-attribute-sets="base">
            <xsl:value-of select="."/>
        </fo:wrapper>
        <xsl:apply-templates select="../Page" mode="do"/>
    </xsl:template>

    <xsl:template match="Page" mode="do">
        <fo:wrapper xsl:use-attribute-sets="base">
            <xsl:text> p.</xsl:text>
            <xsl:value-of select="."/>
        </fo:wrapper>. </xsl:template>

    <xsl:attribute-set name="rebus">
        <xsl:attribute name="text-align">center</xsl:attribute>
        <xsl:attribute name="font-family">Times New Roman</xsl:attribute>
        <xsl:attribute name="font-weight">bold</xsl:attribute>
        <xsl:attribute name="font-size">24pt</xsl:attribute>
        <xsl:attribute name="space-before.minimum">0.25in</xsl:attribute>
        <xsl:attribute name="space-before.optimum">0.25in</xsl:attribute>
        <xsl:attribute name="space-before.maximum">0.25in</xsl:attribute>
        <xsl:attribute name="space-before.conditionality">retain</xsl:attribute>
        <xsl:attribute name="space-after">0.1in</xsl:attribute>
    </xsl:attribute-set>

    <xsl:attribute-set name="base">
        <xsl:attribute name="font-family">Times New Roman</xsl:attribute>
        <xsl:attribute name="font-style">normal</xsl:attribute>
        <xsl:attribute name="font-weight">normal</xsl:attribute>
        <xsl:attribute name="font-size">10pt</xsl:attribute>
    </xsl:attribute-set>

    <xsl:attribute-set name="numbers">
        <!--  <xsl:attribute name="space-before.minimum">1em</xsl:attribute> -->
        <xsl:attribute name="font-weight">bold</xsl:attribute>
        <xsl:attribute name="start-indent">4em</xsl:attribute>
        <xsl:attribute name="text-indent">-4em</xsl:attribute>
    </xsl:attribute-set>

    <xsl:attribute-set name="title">
        <xsl:attribute name="font-style">italic</xsl:attribute>
        <xsl:attribute name="font-weight">normal</xsl:attribute>
    </xsl:attribute-set>

</xsl:stylesheet>
